import os
from distutils.core import setup
from writingfield import get_version

root_dir = os.path.dirname(__file__)
if root_dir != '':
    os.chdir(root_dir)

setup(
    name='django-writingfield',
    version=get_version(),
    license='BSD 3 Clause',
    description='A fullscreen textfield widget for Django',
    long_description=open('README.md').read(),
    author='Obscure Metaphor LTD',
    author_email='hello@obscuremetaphor.co.uk',
    url='https://github.com/obscuremetaphor/django-writingfield',
    package_data={
        'writingfield' : [
            'static/writingfield/*.js',
            'static/writingfield/*.css',
        ],
    },
    packages=[
        'writingfield',
    ],)



from django.forms import Textarea

class FullScreenTextarea(Textarea):

    def __init__(self, attrs=None):
        default_attrs = {'class': 'fullscreen'}
        if attrs is None:
            attrs = default_attrs 
        attrs.update(default_attrs)
        super(FullScreenTextarea, self).__init__(attrs)

    class Media:
        css = {
            'screen': (
                'http://fonts.googleapis.com/css?family=Lato',
                'writingfield/writingfield.css',)
        }
        js = (
            'writingfield/mousetrap.min.js',
            'writingfield/writingfield.js',
        )
